"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/symbol_kind.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bscripting/symbol_kind.proto\x12\x18ares.datamodel.scripting*\xef\x01\n\nSymbolKind\x12\x1b\n\x17SYMBOL_KIND_UNSPECIFIED\x10\x00\x12\x16\n\x12SYMBOL_KIND_DEVICE\x10\x01\x12\x18\n\x14SYMBOL_KIND_FUNCTION\x10\x02\x12\x18\n\x14SYMBOL_KIND_VARIABLE\x10\x03\x12\x16\n\x12SYMBOL_KIND_STRUCT\x10\x04\x12\x17\n\x13SYMBOL_KIND_KEYWORD\x10\x05\x12\x17\n\x13SYMBOL_KIND_PLANNER\x10\x06\x12\x18\n\x14SYMBOL_KIND_ANALYZER\x10\x07\x12\x14\n\x10SYMBOL_KIND_TYPE\x10\x08b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.symbol_kind_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SYMBOLKIND']._serialized_start = 58
    _globals['_SYMBOLKIND']._serialized_end = 297